@@ -612,6 +612,18 @@ func TestSkip(t *testing.T) {
 		require.True(t, Pipe{}.Skip(ctx))
 	})
 
+	t.Run("skip upload", func(t *testing.T) {
+		ctx := context.New(config.Project{
+			Release: config.Release{
+				SkipUpload: true,
+			},
+		})
+		client := &client.Mock{}
+		testlib.AssertSkipped(t, doPublish(ctx, client))
+		require.True(t, client.CreatedRelease)
+		require.False(t, client.UploadedFile)
+	})
+
 	t.Run("dont skip", func(t *testing.T) {
 		require.False(t, Pipe{}.Skip(context.New(config.Project{})))
 	})
